#include <QtGui/QApplication>
#include <QFont>
#include "mainwindow.h"

int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
  //  QTranslator translator;
    //bool loaded = translator.load("mprayertime_ar");
   // if (loaded){
   //    qDebug("Is loaded");
  //  }
  //  a.installTranslator(&translator);
    MainWindow w;
    if(argc > 2 && strncmp(argv[1],"nogui",5) == 0){
        w.printTimes(argv[2]);
    } else {
        w.show();
    }
    return a.exec();
}
